is_valid_lifetime_combination

Function is_valid_lifetime_combination 

pub fn is_valid_lifetime_combination(
    min_lifetime: Option<UInt>,
    max_lifetime: Option<UInt>,
) -> bool
Available on crate features events and unstable-msc1763 only.
Validate a retention lifetime pair.

Returns false if both lifetimes are defined and the max lifetime is smaller than the min lifetime.