#[non_exhaustive]pub struct RoomRetentionEventContent { /* private fields */ }events and unstable-msc1763 only.Expand description
The content of an m.room.retention state event.
The m.room.retention state event lets room admins or moderators set or modify the history
retention behaviour for a given room.
This event uses the unstable prefix defined in MSC1763.
Implementations
Sourceimpl RoomRetentionEventContent
impl RoomRetentionEventContent
Sourcepub fn new() -> RoomRetentionEventContent
pub fn new() -> RoomRetentionEventContent
Create a new RoomRetentionEventContent with no retention limits set.
This method can be combined with the RoomRetentionEventContent::at_least and
RoomRetentionEventContent::at_most methods to configure the individual limits.
Examples
let content = RoomRetentionEventContent::new()
.at_least(Duration::from_hours(24))?
.at_most(Duration::from_hours(24 * 10))?;Sourcepub fn from_range(
lifetime_range: impl RangeBounds<Duration>,
) -> Option<RoomRetentionEventContent>
pub fn from_range( lifetime_range: impl RangeBounds<Duration>, ) -> Option<RoomRetentionEventContent>
Create a new RoomRetentionEventContent from a range.
Returns None if the duration of one of the limits, expressed as milliseconds, doesn’t
fall into the [0, (2^53)-1] range, or if the lower bound of the range is bigger than the
upper bound, i.e. 10..0.
Examples
let content = RoomRetentionEventContent::from_range(
Duration::from_hours(24)..Duration::from_hours(24 * 10),
)?;Sourcepub fn at_most(self, max: Duration) -> Option<RoomRetentionEventContent>
pub fn at_most(self, max: Duration) -> Option<RoomRetentionEventContent>
Set the maximum amount of time a message should be kept on the homeserver.
Returns None if the given limit, expressed as milliseconds, doesn’t fall into the [0,
(2^53)-1] range, or if the limits don’t adhere to the max < min constraint.
Sourcepub fn at_least(self, min: Duration) -> Option<RoomRetentionEventContent>
pub fn at_least(self, min: Duration) -> Option<RoomRetentionEventContent>
Set the minimum amount of time a message should be kept on the homeserver.
Returns None if the given limit, expressed as milliseconds, doesn’t fall into the [0,
(2^53)-1] range, or if the limits don’t adhere to the max < min constraint.
Sourcepub fn max_lifetime(&self) -> Option<Duration>
pub fn max_lifetime(&self) -> Option<Duration>
Get the maximum event lifetime defined by this state event, if any.
Sourcepub fn min_lifetime(&self) -> Option<Duration>
pub fn min_lifetime(&self) -> Option<Duration>
Get the minimum event lifetime defined by this state event, if any.