pub fn is_valid_lifetime_combination(
min_lifetime: Option<UInt>,
max_lifetime: Option<UInt>,
) -> boolAvailable on crate features
events and unstable-msc1763 only.Expand description
Validate a retention lifetime pair.
Returns false if both lifetimes are defined and the max lifetime is smaller than the min lifetime.