pub type InitialRoomRetentionEvent = InitialStateEvent<RoomRetentionEventContent>;Available on crate features
events and unstable-msc1763 only.Expand description
An org.matrix.msc1763.retention event for creating a room.
Aliased Type
pub struct InitialRoomRetentionEvent {
pub content: RoomRetentionEventContent,
pub state_key: EmptyStateKey,
}Fields
content: RoomRetentionEventContentData specific to the event type.
state_key: EmptyStateKeyA unique key which defines the overwriting semantics for this piece of room state.
This must be a string type, and is often an empty string.
A state event is keyed by its (type, state_key) tuple. Sending another state event with
the same tuple replaces the previous one.
Defaults to the empty string.